%bcond_with network
%global _hardened_build 1

Summary:  The Network Mapper
Name:     nmap
Version:  7.93
Release:  2%{?dist}
URL:      http://nmap.org/
License:  Nmap
Source0:  http://nmap.org/dist/%{name}-%{version}.tar.bz2
# https://bugzilla.redhat.com/show_bug.cgi?id=158996
Patch3000: nmap-4.03-mktemp.patch
Patch3001: nmap-4.52-noms.patch
# https://bugzilla.redhat.com/show_bug.cgi?id=845005
Patch3002: ncat_reg_stdin.diff
Patch3003: nmap-6.25-displayerror.patch
# https://github.com/nmap/nmap/pull/2247
Patch3004: nmap_resolve_config.patch

BuildRequires: gcc-c++, automake, make, autoconf,
BuildRequires:  gettext-devel, libpcap-devel, libssh2-devel, libtool, openssl-devel, pcre-devel, zlib-devel

Requires: %{name}-ncat = %{version}-%{release}

%description
Nmap (“Network Mapper”) is an open source tool for network exploration and 
security auditing. It was designed to rapidly scan large networks, although it 
works fine against single hosts. Nmap uses raw IP packets in novel ways to 
determine what hosts are available on the network, what services (application 
name and version) those hosts are offering, what operating systems (and OS 
versions) they are running, what type of packet filters/firewalls are in use, 
and dozens of other characteristics. While Nmap is commonly used for security 
audits, many systems and network administrators find it useful for routine 
tasks such as network inventory, managing service upgrade schedules, and 
monitoring host or service uptime.

%package ncat
Summary: Nmap's Netcat replacement
Requires(post): %{_sbindir}/alternatives
Requires(preun): %{_sbindir}/alternatives
Provides: nc nc6

%description ncat
Ncat is a feature-packed networking utility which reads and writes data across 
networks from the command line. Ncat was written for the Nmap Project and is 
the culmination of the currently splintered family of Netcat incarnations. It 
is designed to be a reliable back-end tool to instantly provide network 
connectivity to other applications and users. Ncat will not only work with IPv4
and IPv6 but provides the user with a virtually limitless number of potential 
uses.


%prep
%autosetup -p1

rm -rf libpcap libpcre macosx mswin32 libssh2 libz



%build
export CFLAGS="%{build_cflags} -fno-strict-aliasing"
export CXXFLAGS="%{build_cxxflags} -fno-strict-aliasing"
%configure  \
  --with-libpcap=yes \
  --with-liblua=included \
  --with-libssh2=yes \
  --with-liblinear=included \
  --with-libpcre=yes \
  --with-libdnet=included \
  --with-libz=yes \
  --without-zenmap \
  --without-ndiff \
  --enable-dbus 

%make_build 

sed -i 's/-md/-mf/' nping/docs/nping.1



%install
make DESTDIR=%{buildroot} STRIP=true install

rm -f %{buildroot}%{_datadir}/ncat/ca-bundle.crt
rmdir %{buildroot}%{_datadir}/ncat

touch %{buildroot}%{_mandir}/man1/nc.1.gz
touch %{buildroot}%{_bindir}/nc

%find_lang nmap --with-man



%check
%if %{with network}
# there may be some errors in cheching
make check
%endif




%post ncat
%{_sbindir}/alternatives --install %{_bindir}/nc nc %{_bindir}/ncat 10 \
  --slave %{_mandir}/man1/nc.1.gz nc-man %{_mandir}/man1/ncat.1.gz

%preun ncat
if [ $1 -eq 0 ]; then
  %{_sbindir}/alternatives --remove nc %{_bindir}/ncat
fi



%files -f nmap.lang
%license LICENSE
%doc docs/README
%doc docs/nmap.usage.txt
%{_bindir}/nmap
%{_bindir}/nping
%{_datadir}/nmap
%{_mandir}/man1/nmap.1.gz
%{_mandir}/man1/nping.1.gz

%files ncat 
%license LICENSE
%doc ncat/docs/AUTHORS ncat/docs/README ncat/docs/THANKS ncat/docs/examples
%ghost %{_bindir}/nc
%{_bindir}/ncat
%ghost %{_mandir}/man1/nc.1.gz
%{_mandir}/man1/ncat.1.gz

%changelog
* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 7.93-2
- Rebuilt for OpenCloudOS Stream 23.09

* Thu Aug 17 2023 Shuo Wang <abushwang@tencent.com> - 7.93-1
- update to 7.93

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 7.92-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 7.92-2
- Rebuilt for OpenCloudOS Stream 23

* Thu Sep 01 2022 Zhao Zhen <jeremiazhao@tencent.com> - 7.92-1
- Initial building
